==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF69S.sql <==
/****************************************************************************/
/* GF69 ( 不具合対策管理ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF69 (
   PRJCODE      VARCHAR2 (   30 )                   NOT NULL            /*  10 PRJｺｰﾄﾞ      */
 , PHASE        VARCHAR2 (    1 )                   NOT NULL            /*  20 実施ﾌｪｰｽﾞ    */
 , SEQNO        NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  30 表示順       */
 , DYACC        VARCHAR2 (    8 )                                       /*  40 発生日       */
 , PRG_NAME     VARCHAR2 (  120 )                                       /*  50 処理名称     */
 , PGID         VARCHAR2 (   30 )                                       /*  60 PG-ID        */
 , SINSEI       VARCHAR2 (   30 )                                       /*  70 申請者       */
 , TRBL_CONT    VARCHAR2 ( 4000 )                                       /*  80 ﾄﾗﾌﾞﾙ内容    */
 , ZANTEI       VARCHAR2 ( 4000 )                                       /*  90 暫定対策     */
 , CDIMP        VARCHAR2 (    1 )                                       /* 100 重要度       */
 , CDCONT       VARCHAR2 (    1 )                                       /* 110 要因         */
 , CASUS        VARCHAR2 ( 4000 )                                       /* 120 原因         */
 , BIKO         VARCHAR2 ( 2000 )                                       /* 130 備考         */
 , RESOURCE_ID  NUMBER   (    9 )                                       /* 140 ﾘｿｰｽID       */
 , ACT_CONT     VARCHAR2 ( 4000 )                                       /* 150 対策内容     */
 , DYYOTE       VARCHAR2 (    8 )                                       /* 160 予定         */
 , DYKAN        VARCHAR2 (    8 )                                       /* 170 完成日       */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF69S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF69T00 
  BEFORE INSERT ON GF69
  FOR EACH ROW 
  BEGIN 
    SELECT GF69S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF69S.sql <==
/****************************************************************************/
/* GF69 ( 不具合対策管理ﾃｰﾌﾞﾙ )                                             */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF69 (
   PRJCODE      VARCHAR2 (   30 )                   NOT NULL            /*  10 PRJｺｰﾄﾞ      */
 , PHASE        VARCHAR2 (    1 )                   NOT NULL            /*  20 実施ﾌｪｰｽﾞ    */
 , SEQNO        NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  30 表示順       */
 , DYACC        VARCHAR2 (    8 )                                       /*  40 発生日       */
 , PRG_NAME     VARCHAR2 (  120 )                                       /*  50 処理名称     */
 , PGID         VARCHAR2 (   30 )                                       /*  60 PG-ID        */
 , SINSEI       VARCHAR2 (   30 )                                       /*  70 申請者       */
 , TRBL_CONT    VARCHAR2 ( 4000 )                                       /*  80 ﾄﾗﾌﾞﾙ内容    */
 , ZANTEI       VARCHAR2 ( 4000 )                                       /*  90 暫定対策     */
 , CDIMP        VARCHAR2 (    1 )                                       /* 100 重要度       */
 , CDCONT       VARCHAR2 (    1 )                                       /* 110 要因         */
 , CASUS        VARCHAR2 ( 4000 )                                       /* 120 原因         */
 , BIKO         VARCHAR2 ( 2000 )                                       /* 130 備考         */
 , RESOURCE_ID  NUMBER   (    9 )                                       /* 140 ﾘｿｰｽID       */
 , ACT_CONT     VARCHAR2 ( 4000 )                                       /* 150 対策内容     */
 , DYYOTE       VARCHAR2 (    8 )                                       /* 160 予定         */
 , DYKAN        VARCHAR2 (    8 )                                       /* 170 完成日       */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF69S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF69T00 
  BEFORE INSERT ON GF69
  FOR EACH ROW 
  BEGIN 
    SELECT GF69S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
